import { HttpServerBoot } from './core/http';
import { JobsBoot } from './core/jobs';
import * as ioc from './ioc';
import { DataBoot } from './core/data';
import { AwsQueueBoot } from './core/queues';
import { FrameworkConfig } from './shared/types';
export declare class FilooCore {
    readonly config: FrameworkConfig;
    httpServerBoot: HttpServerBoot | null;
    awsQueueBoot: AwsQueueBoot | null;
    jobsBoot: JobsBoot | null;
    dataBoot: DataBoot | null;
    constructor(config: FrameworkConfig);
    get ioc(): ioc.IocManager;
    /**
     * Método opcional e utilitário q pode tentar startar todos os serviços do framework.
     */
    startAll(): Promise<void>;
    startData(): Promise<void>;
    /**
     * Força o carregamento de arquivos para que sejam registrados no Ioc.
     * Estes arquivos serão apenas importados e registrados.
     * WARN: Cuidado com os arquivos que possuem a intenção de singleton, pois serão instanciados ao serem importados.
     * @param path
     */
    preloadDirectories(path: string): Promise<any[]>;
    /**
     * Carrega dinamicamente os arquivos de controllers, os instancia e os regista no Ioc, mas não inicia o server http.
     * Após o boot de todas os rest controllers, para iniciar o server http é necessário executar o método startHttpServer.
     * TODAS AS CLASSES DOS CONTROLLERS DEVEM EXPORTAR UMA CLASSE DEFAULT.
     * @param restControllersPath
     * @param restIntercerptorsPath
     */
    prepareControllersAndInterceptors(restControllersPath: string, restIntercerptorsPath?: string): Promise<void>;
    /**
     * Carrega dinamicamente os arquivos de controllers de queues, os instancia e os regista no Ioc, mas não inicia os consumers no SQS.
     * Após o boot de todas as Queues, para iniciar os consumers é necessário executar o método startConsumersAwsQueues.
     * TODAS AS CLASSES DAS AwsQueueController(decorator) DEVEM EXPORTAR UMA CLASSE DEFAULT.
     * @param queueControllersPresentationPath
     */
    prepareAwsQueues(queueControllersPresentationPath: string): Promise<void>;
    /**
     * Inicia os jobs registrados
     */
    startJobs(): Promise<void>;
    /**
     * Inicia os consumers de queues no SQS registrados pelo método prepareAwsQueues
     */
    startConsumersAwsQueues(): Promise<void>;
    /**
     * Inicia o server http, contendo as rotas e configurações registradas pelo método prepareControllersAndInterceptors
     */
    startHttpServer(): Promise<void>;
    stopHttpServer(): Promise<void>;
}
